Learn R Programming

SportMiner (version 0.1.0)

convert_dtm_to_stm: Convert DTM to STM Format

Description

Helper function to convert a DocumentTermMatrix to the format required by the stm package.

Usage

convert_dtm_to_stm(dtm)

Value

A list with documents and vocab components for stm.

Arguments

dtm

A DocumentTermMatrix object.